@@ -1,42 +1,47 @@
 $VAR1 = {
-          'language' => 'en',
-          'config' => '/var/www/cgi-bin/config/settings.pl',
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'scriptAlias' => 'cgi-bin',
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'cgi' => {
-                     'DocumentRoot' => '/var/www/htdocs',
-                     'cookiePath' => '/',
-                     'title' => 'MySQL::Admin',
-                     'bin' => '/var/www/cgi-bin',
-                     'expires' => '+1y',
-                     'alias' => 'cgi-bin',
-                     'serverName' => 'http://localhost',
-                     'style' => 'mysql'
-                   },
-          'floodtime' => 10,
-          'admin' => {
-                       'name' => 'Lindner',
-                       'email' => 'dirk.lze@gmail.com',
-                       'firstname' => 'Dirk',
-                       'password' => 'testpass'
-                     },
-          'version' => '0.77',
-          'files' => {
-                       'group' => 'www-data',
-                       'chmod' => '0755',
-                       'owner' => 'www-data'
-                     },
           'database' => {
-                          'password' => 'keinz',
+                          'CurrentHost' => 'localhost',
+                          'CurrentUser' => 'root',
                           'host' => 'localhost',
-                          'name' => 'LZE',
                           'user' => 'root',
                           'CurrentPass' => 'keinz',
-                          'CurrentUser' => 'root',
-                          'CurrentHost' => 'localhost',
+                          'password' => 'keinz',
+                          'name' => 'LZE',
                           'CurrentDb' => 'LZE'
                         },
-          'session' => '/var/www/cgi-bin/config/session.pl'
+          'mod' => undef,
+          'cgi' => {
+                     'title' => 'MySQL::Admin',
+                     'serverName' => 'myadmin.localhost',
+                     'bin' => '/var/www/cgi-bin',
+                     'alias' => 'perl',
+                     'DocumentRoot' => '/var/www/htdocs',
+                     'cookiePath' => '/',
+                     'expires' => '+1y',
+                     'style' => 'mysql'
+                   },
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'admin' => {
+                       'email' => 'dirk.lze@gmail.com',
+                       'password' => 'testpass'
+                     },
+          'session' => '/var/www/cgi-bin/config/session.pl',
+          'scriptAlias' => 'perl',
+          'uploads' => {
+                         'maxlength' => 21000000,
+                         'chmod' => 438,
+                         'path' => '/var/www/htdocs/download'
+                       },
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'apacheconfig' => undef,
+          'files' => {
+                       'chmod' => '0755',
+                       'owner' => 'www-data',
+                       'group' => 'www-data'
+                     },
+          'version' => '0.79',
+          'floodtime' => 10,
+          'language' => 'en',
+          'actions' => '/var/www/cgi-bin/config/actions.pl'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
