@@ -5,12 +5,12 @@ use utf8;
 use HTML::Entities;
 use vars qw( 
   $m_dbh
-  $m_dsn 
+  $m_dsn
   $m_sDefaultClass 
-  @EXPORT_OK 
+  @EXPORT_OK
   @ISA 
   %m_hFunctions
-  $m_sServerName 
+  $m_sServerName
   $m_nSecs
 );
 $m_sDefaultClass = 'DBI::Library::Database' unless defined $DBI::Library::Database::m_sDefaultClass;
@@ -18,20 +18,14 @@ require Exporter;
 use DBI::Library qw(:all $m_dbh $m_dsn);
 @DBI::Library::Database::ISA    = qw(DBI::Library Exporter);
 @DBI::Library::Database::EXPORT = qw(useexecute);
-@DBI::Library::Database::EXPORT_OK =
-  qw(getIndex CurrentPass CurrentUser CurrentHost CurrentDb Driver execute useexecute quote void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute tableLength tableExists addUser hasAcount isMember right checkPass checkSession setSid getName initDB checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string);
+@DBI::Library::Database::EXPORT_OK = qw(getIndex CurrentPass CurrentUser CurrentHost CurrentDb Driver execute useexecute quote void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute tableLength tableExists addUser hasAcount isMember right checkPass checkSession setSid getName initDB checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string);
 %DBI::Library::Database::EXPORT_TAGS = (
-    'all' => [
-        qw(getIndex CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right checkPass checkSession setSid getName initDB tableLength tableExists useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute  checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string)
-    ],
+    'all' => [ qw(getIndex CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right checkPass checkSession setSid getName initDB tableLength tableExists useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute  checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue fetch_string)],
     'dynamic' => [qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute)],
-    'independent' =>
-      [qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver tableLength tableExists initDB useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute fetch_string)],
-    'lze' => [
-        qw(getIndex CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right checkPass checkSession setSid getName checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue)
-    ],
+    'independent' => [qw(CurrentPass CurrentUser CurrentHost CurrentDb Driver tableLength tableExists initDB useexecute void fetch_hashref fetch_AoH fetch_array updateModules deleteexecute editexecute addexecute fetch_string)],
+    'lze' => [ qw(getIndex CurrentPass CurrentUser CurrentHost CurrentDb Driver addUser hasAcount isMember right checkPass checkSession setSid getName checkFlood GetColumns GetAttrs GetCollation GetColumnCollation GetExtra GetNull GetEngineForRow GetEngines GetCharacterSet GetDataBases GetAutoIncrement GetPrimaryKey GetAutoIncrementValue) ],
 );
-$DBI::Library::Database::VERSION = '0.77';
+$DBI::Library::Database::VERSION = '0.79';
 $m_nSecs                         =  10;
 
 =head1 NAME
@@ -44,7 +38,7 @@ use DBI::Library::Database;
 
 =head2 new()
 
-      constructor
+constructor
 
 =cut
 
@@ -67,15 +61,18 @@ sub getName
 {
     my ($self, @p) = getSelf(@_);
     my $m_sSid = $p[0];
-    if (defined $m_sSid) {
-        my $sql = 'SELECT user FROM `users` where sid = ?;';
-        my $sth = $m_dbh->prepare($sql) or warn $m_dbh->errstr;
-        $sth->execute($m_sSid) or warn $m_dbh->errstr;
-        my $name = $sth->fetchrow_array();
-        $sth->finish();
-        return $name;
-    } else {
-        return 'guest';
+    if (defined $m_sSid) 
+    {
+      my $sql = 'SELECT user FROM `users` where sid = ?;';
+      my $sth = $m_dbh->prepare($sql) or warn $m_dbh->errstr;
+      $sth->execute($m_sSid) or warn $m_dbh->errstr;
+      my $name = $sth->fetchrow_array();
+      $sth->finish();
+      return $name;
+    }
+    else 
+    {
+      return 'guest';
     }
 }
 
@@ -109,7 +106,7 @@ sub setSid
 
 =head2 checkSession
 
-      $bool = $m_oDatabase->checkSession($m_sUser,$m_sSid);
+    $bool = $m_oDatabase->checkSession($m_sUser,$m_sSid);
 
 =cut
 
@@ -197,8 +194,8 @@ sub topicright
     my ($self, @p) = getSelf(@_);
     my $id  = $p[0];
     my $sql = 'SELECT `right` FROM news where id = ?';
-    my $sth = $m_dbh->prepare($sql);
-    $sth->execute($id);
+    my $sth = $m_dbh->prepare( $sql );
+    $sth->execute( $id );
     my @q = $sth->fetchrow_array;
     $sth->finish();
     return $q[0];
@@ -206,7 +203,7 @@ sub topicright
 
 =head2 catright()
 
-      catright('name|name2');
+    catright( 'name|name2' );
 
 =cut
 
@@ -219,7 +216,8 @@ sub catright
     $sel{$_}   = 1 foreach @select;
     my @cats   = $self->fetch_AoH('SELECT * FROM cats');
     my $nRight = 0;
-    for( my $i = 0; $i <= $#cats; $i++ ){
+    for( my $i = 0; $i <= $#cats; $i++ )
+    {
         $nRight = $cats[$i]->{right} if ($sel{$cats[$i]->{name}} && $cats[$i]->{right} > $nRight);
     }
     return $nRight;
@@ -235,13 +233,16 @@ sub isMember
 {
     my ($self, @p) = getSelf(@_);
     my $m_sUser = lc $p[0];
-    if (defined $m_sUser) {
+    if (defined $m_sUser)
+    {
         my $sth = $m_dbh->prepare('SELECT user  FROM users where user = ?') or warn $m_dbh->errstr;
         $sth->execute($m_sUser);
         my ($member) = $sth->fetchrow_array();
         $sth->finish();
         return defined $member ? ($m_sUser eq $member) ? 1 : 0 : 0;
-    } else {
+    }
+    else 
+    {
         return 1;
     }
 }
@@ -300,9 +301,12 @@ set serverName.
 sub serverName
 {
     my ($self, @p) = getSelf(@_);
-    if (defined $p[0]){
+    if (defined $p[0])
+    {
       $m_sServerName = $p[0];
-    }else{
+    }
+    else
+    {
       return $m_sServerName;
     }
 }
@@ -316,9 +320,12 @@ set floodtime.
 sub floodtime
 {
     my ($self, @p) = getSelf(@_);
-    if (defined $p[0]){
+    if (defined $p[0])
+    {
       $m_nSecs = $p[0];
-    }else{
+    }
+    else
+    {
       return $m_nSecs;
     }
 }
@@ -346,11 +353,14 @@ sub checkFlood
         my $sth = $m_dbh->prepare($sql) or warn $m_dbh->errstr;
         $sth->execute($ip);
         my $ltime = $sth->fetchrow_array();
-        unless (defined $ltime) {
+        unless (defined $ltime)
+        {
             $self->void('insert into flood (remote_addr, ti) VALUES(?,?)', $ip, time());
             $return = 1;
-        } else {
-            $return = (time() - $ltime > $m_nSecs) ? 1 : 0;
+        }
+        else
+        {
+            $return = ( time() - $ltime > $m_nSecs ) ? 1 : 0;
             $self->void('update flood set ti =?  where remote_addr = ?', time(), $ip);
         }
         $sth->finish();
@@ -369,7 +379,8 @@ sub GetAutoIncrementValue
     my ($self, @p) = getSelf(@_);
     my $name = $p[0];
     my @a = $self->fetch_AoH('SHOW TABLE STATUS');
-    for (my $i = 0; $i <= $#a; $i++) {
+    for (my $i = 0; $i <= $#a; $i++)
+    {
         return $a[$i]->{Auto_increment} if ($a[$i]->{Name} eq $name);
     }
 }
@@ -386,11 +397,13 @@ sub GetPrimaryKey
 {
     my ($self, @p) = getSelf(@_);
     my $tbl = $p[0];
-    if( defined $tbl ) {
+    if( defined $tbl )
+    {
         $tbl = $m_dbh->quote_identifier($tbl);
         my @caption = $self->fetch_AoH("show columns from $tbl");
         my @return;
-        for (my $j = 0; $j <= $#caption; $j++) {
+        for (my $j = 0; $j <= $#caption; $j++)
+        {
             push @return, $caption[$j]->{'Field'} if ($caption[$j]->{'Key'} eq 'PRI');
         }
         push @return, $caption[0]->{'Field'} if $#caption eq 0;
@@ -421,16 +434,16 @@ sub getIndex
 	      my @fields;
 	      push @fields, /`([^`]+)`/ for split ',' , $5;
 	      if($line =~/REFERENCES `([^`]+)` \(([^)]+)\)/){
-		my $table= $1;     
+		my $table= $1;
 		my @references;
 		push @references, /`([^`]+)`/ for split ',' , $2;
-		push @return, {
-		    field         =>  /`([^`]+)`/,
-		    foreignTable  =>  $table,
-		    foreignFields =>  [@fields],
+		push @return,{
+		    field             =>  /`([^`]+)`/,
+		    foreignTable      =>  $table,
+		    foreignFields     =>  [@fields],
 		    foreignReferences =>  [@references],
-		    name  => $name,
-		    type  => $type,
+		    name              => $name,
+		    type              => $type,
 		    ondelete => $line =~/ON DELETE CASCADE/ ? 'CASCADE' :$line =~/ON DELETE SET DEFAULT/ ? 'SET DEFAULT' :'',
 		    onupdate => $line =~/ON UPDATE CASCADE/ ? 'CASCADE' :$line =~/ON UPDATE SET DEFAULT/ ? 'SET DEFAULT' :'',
 		} for split ',' , $sfields;
@@ -457,15 +470,18 @@ sub getConstraintKeys
     my $tbl = $p[0];
     my $key = $p[1];
     my @return;
-    if (defined $tbl){
+    if (defined $tbl)
+    {
 	$tbl = $m_dbh->quote_identifier($tbl);
         my $hr =   $self->fetch_hashref("SHOW CREATE TABLE $tbl");
   	foreach my $line ( split /\n/,$hr->{'Create Table'}){
 	  my %keys;
-	  if($line =~/CONSTRAINT `([^`]+)` FOREIGN KEY \(([^)]+)\)/){
+	  if($line =~/CONSTRAINT `([^`]+)` FOREIGN KEY \(([^)]+)\)/)
+	  {
 	    my $i = 0;
-	    for( split ',' ,$2){
-	      /`([^`]+)`/ ;
+	    for( split ',' ,$2)
+	    {
+	      /`([^`]+)`/;
 	      $keys{$1} = 1;
 	    }
 	    push @return, $1 if($keys{$key} and $return[$#return-1] ne $1 );
@@ -477,7 +493,7 @@ sub getConstraintKeys
 
 =head2 GetAutoIncrement()
 
-    returns  the auto_increment Column.
+    returns the auto_increment Column.
 
     GetAutoIncrement(table)
 
@@ -491,11 +507,14 @@ sub GetAutoIncrement
         $tbl = $m_dbh->quote_identifier($tbl);
         my @caption = $self->fetch_AoH("show columns from $tbl");
         my $r;
-        for (my $j = 0; $j <= $#caption; $j++) {
+        for (my $j = 0; $j <= $#caption; $j++)
+        {
             $r = $caption[$j]->{'Field'} if ($caption[$j]->{'Extra'} eq 'auto_increment');
         }
         return $r;
-    } else {
+    }
+    else 
+    {
         return 0;
     }
 }
